@@ -1,3 +1,5 @@
+from .audio_web_dataset import AudioWebDataset, AudioWebDatasetPreprocess
+from .clotho_dataset import ClothoDataset
 from .common_voice_dataset import CommonVoiceDataset
 from .libri_speech_dataset import LibriSpeechDataset
 from .lj_speech_dataset import LJSpeechDataset
